@@ -6,6 +6,7 @@ from vortex.handler.TupleActionProcessorProxy import TupleActionProcessorProxy
 
 def makeTupleActionProcessorProxy():
     return TupleActionProcessorProxy(
-                tupleActionProcessorName=gisDiagramActionProcessorName,
-                proxyToVortexName=peekServerName,
-                additionalFilt=gisDiagramFilt)
+        tupleActionProcessorName=gisDiagramActionProcessorName,
+        proxyToVortexName=peekServerName,
+        additionalFilt=gisDiagramFilt,
+    )
